/*
    This file is part of the 'yarec' package.
    Copyright (C) 1998  Ralf W. Stephan <stephan@tmt.de>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#ifdef HAVE_CONFIG_H
# include <config.h>
#endif
#include "yarec.h"

#include <stdio.h>

struct File {
	char* name;
	FILE* fp;
	int wflag;
	long size;
};

struct File* File_init (const char*);
void File_begin_read (const struct File*);
void File_append (const struct File*);
void File_write_new (const struct File*);
int File_ok (const struct File*);
int File_wflag (const struct File*);
int File_empty (const struct File*);
const char* File_name (const struct File*);
void File_set_size (const struct File*, long);
long File_size (const struct File*);
long File_size (const struct File* f);
void File_seek (const struct File* f, long pos);
void File_seek_end (const struct File* f);
long File_tell (const struct File* f);
void File_reset (const struct File* f);
void File_close (const struct File*);

void Format_init (const struct File*, int);
void Format_get_params (int *r, int *b, int *c);
void Format_set_params (int r, int b, int c, int contd);
typedef void (*conv_func_t)(u32*, long);
conv_func_t Format_get_conversion();
int Format_get_chunk (u32*, long);
void Format_write_chunk (u32*, long);
void Format_close();
