/*
    This file is part of the 'yarec' package.
    Copyright (C) 1998  Ralf W. Stephan <stephan@tmt.de>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#include "tasks/tasks.h"

extern int Task_record_init (int);
extern int Task_record_timeout();
extern void Task_record_finish (int);
extern int Task_play_init(int);
extern int Task_play_timeout ();
extern void Task_play_finish (int);
extern void Task_write();

static int (*timeoutfunc)();
static int current_task = 0, halted = 0;

void Task_schedule (int c)
{
  if (!c) return;
  
  switch (current_task) {
  case 0  :
  	switch (c) {
  	case 'P':
  		Task_play_init(0);
  		timeoutfunc = Task_play_timeout;
  		current_task = c;
  		break;
  	case 'R':
  		Task_record_init(0);
  		timeoutfunc = Task_record_timeout;
  		current_task = c;
  		break;
  	case 'W':
  		Task_write();
  		break;
  	}
  	break;

  case 'P':
  	switch (c) {
  	case 'P':
  		if (halted) {
  			Task_play_init (1);
  			halted = 0;
  		}
  		break;
  	case 'R':
  		/* do nothing, even when halted */
  		/* reasoning: asked two people what behaviour they'd expect */
  		break;
  	case 'H':
  		if (!halted) 
  			Task_play_finish(1);
  		else
  			Task_play_init(1);
  		halted = !halted;
  		break;
  	case 'S':
  		Task_play_finish(0);
  		timeoutfunc = 0;
  		current_task = 0;
  		halted = 0;
  		break;
  	case 'W':
  		Task_play_finish(0);
  		Task_write();
  		timeoutfunc = 0;
  		current_task = 0;
  		halted = 0;
  		break;
  	}
  	break;

  case 'R':
  	switch (c) {
  	case 'P':
  		if (halted) {
  			Task_record_init (1);
  			halted = 0;
  		}
  		break;
  	case 'R':
  		if (halted) {
  			Task_record_init (1);
  			halted = 0;
  		}
  		break;
  	case 'H':
  		if (!halted) 
  			Task_record_finish(1);
  		else
  			Task_record_init(1);
  		halted = !halted;
  		break;
  	case 'S':
  		Task_record_finish(0);
  		timeoutfunc = 0;
  		current_task = 0;
  		halted = 0;
  		break;
  	case 'W':
  		Task_record_finish(0);
  		Task_write();
  		timeoutfunc = 0;
  		current_task = 0;
  		halted = 0;
  		break;
  	}
  	break;
  }
}

int Task_timeout()
{
  int ret;

  if (halted || !timeoutfunc) return 1;
  
  ret = timeoutfunc();
  if (!ret) {
  	timeoutfunc = 0;
  	switch (current_task) {
  	case 'P': Task_play_finish(0); break;
  	case 'R': Task_record_finish(0); break;
  	}
  	current_task = 0;
  }
  
  return ret;
}

